#!/home/rus043/anaconda2/bin/python
import sys, os, os.path
import matplotlib.pyplot as plt
from netCDF4 import Dataset
import numpy as np
from scipy import interpolate

nXX = 256
nYY = 256

hycomSSTFile = './hycom_T_ccs_newtopo_2012060100.bin'
hycomUFile   = './hycom_U_ccs_newtopo_2012060100.bin'
hycomVFile   = './hycom_V_ccs_newtopo_2012060100.bin'
sstRaw    = np.fromfile(hycomSSTFile,dtype='>f4');
uoceRaw   = np.fromfile(hycomUFile,dtype='>f4');
voceRaw   = np.fromfile(hycomVFile,dtype='>f4');
ini_sst   = np.reshape(sstRaw ,(50,256,256));
ini_uoce  = np.reshape(uoceRaw,(50,256,256));
ini_voce  = np.reshape(voceRaw,(50,256,256));
ini_sst_  = ini_sst[0,:,:]+273.15
ini_uoce_ = ini_uoce[0,:,:]
ini_voce_ = ini_voce[0,:,:]

# update wrf input file
wrf_results = Dataset('wrfinput_d01','r+',format='NETCDF4');
wrf_sst = wrf_results.variables['SST'][:];
wrf_tsk = wrf_results.variables['TSK'][:];
wrf_uoce = wrf_results.variables['UOCE'][:];
wrf_voce = wrf_results.variables['VOCE'][:];
wrf_landmask = wrf_results.variables['LANDMASK'][:];

sst_write = np.zeros((nYY,nXX))
tsk_write = np.zeros((nYY,nXX))
uoce_write = np.zeros((nYY,nXX))
voce_write = np.zeros((nYY,nXX))
print 'modifying wrf input file...'
print '  sst before: ', np.mean(wrf_sst)
print '  tsk before: ', np.mean(wrf_tsk)
for i in range(nXX):
  for j in range(nYY):
    # water in MITgcm
    if ini_sst_[j,i] > 273.20:
      sst_write[j,i] = ini_sst_[j,i]
      tsk_write[j,i] = ini_sst_[j,i]
      uoce_write[j,i] = ini_uoce_[j,i]
      voce_write[j,i] = ini_voce_[j,i]
    else:
      sst_write[j,i] = wrf_tsk[0,j,i]
      tsk_write[j,i] = wrf_tsk[0,j,i]
    
print ' sst after: ', np.mean(sst_write)
print ' tsk after: ', np.mean(tsk_write)
print ' uoce/voce after: ', np.mean(uoce_write), np.mean(voce_write)

wrf_results.variables['SST'][0,:,:] = sst_write;
wrf_results.variables['TSK'][0,:,:] = tsk_write;
wrf_results.variables['SST_INPUT'][0,:,:] = tsk_write;
wrf_results.variables['UOCE'][0,:,:] = uoce_write;
wrf_results.variables['VOCE'][0,:,:] = voce_write;

wrf_results.close()

# update wrf low input file
wrf_low_results = Dataset('wrflowinp_d01','r+',format='NETCDF4');
wrf_sst = wrf_low_results.variables['SST'][:];
wrf_ssti = wrf_low_results.variables['SST_INPUT'][:];
wrf_uoce = wrf_low_results.variables['UOCE'][:];
wrf_voce = wrf_low_results.variables['VOCE'][:];

nT, nY, nX = np.shape(wrf_sst)
for k in range(nT):
  wrf_low_results.variables['SST'][k,:,:] = sst_write;
  wrf_low_results.variables['SST_INPUT'][k,:,:] = sst_write;
  wrf_low_results.variables['UOCE'][k,:,:] = uoce_write;
  wrf_low_results.variables['VOCE'][k,:,:] = voce_write;
  print 'step : ', k
  print ' sst after: ', np.mean(wrf_low_results.variables['SST'][k,:,:])
  print ' ssti after: ', np.mean(wrf_low_results.variables['SST_INPUT'][k,:,:])
  print ' uoce after: ', np.mean(wrf_low_results.variables['UOCE'][k,:,:])
  print ' voce after: ', np.mean(wrf_low_results.variables['VOCE'][k,:,:])

wrf_low_results.close()

# plot the debug
plt.imshow(wrf_sst[0,:,:],vmax=32+273.15,vmin=24+273.15)
plt.savefig('fig_sst_before.png');
plt.close('all')
plt.imshow(wrf_tsk[0,:,:],vmax=32+273.15,vmin=24+273.15)
plt.savefig('fig_tsk_before.png');
plt.close('all')
plt.imshow(sst_write,vmax=32+273.15,vmin=24+273.15)
plt.savefig('fig_sst_after.png');
plt.close('all')
plt.imshow(tsk_write,vmax=32+273.15,vmin=24+273.15)
plt.savefig('fig_tsk_after.png');
plt.close('all')

