#!/home/rus043/anaconda2/bin/python
import sys, os, os.path
import matplotlib.pyplot as plt
from netCDF4 import Dataset
import numpy as np
from scipy import interpolate

nXX = 256
nYY = 256
nWaveStep = 0
wave_hs_results = Dataset('ww3.201206_hs.nc','r',format='NETCDF4');
wave_lm_results = Dataset('ww3.201206_lm.nc','r',format='NETCDF4');
wave_hs = wave_hs_results.variables['hs'][nWaveStep,:,:];
wave_lm = wave_lm_results.variables['lm'][nWaveStep,:,:];
wave_lat = wave_lm_results.variables['latitude'][:];
wave_lon = wave_lm_results.variables['longitude'][:];

wrf_results = Dataset('wrfinput_d01','r+',format='NETCDF4');
wrf_hs = wrf_results.variables['WAVEHS'][:];
wrf_lm = wrf_results.variables['WAVELP'][:];
wrf_lat = wrf_results.variables['XLAT'][:];
wrf_lon = wrf_results.variables['XLONG'][:];
wrf_landmask = wrf_results.variables['LANDMASK'][:];

np.ma.set_fill_value(wave_hs,0)
np.ma.set_fill_value(wave_lm,0)
hs_interpolate_fun = interpolate.RectBivariateSpline(wave_lat,wave_lon,wave_hs.filled())
lm_interpolate_fun = interpolate.RectBivariateSpline(wave_lat,wave_lon,wave_lm.filled())
hs_interpolated = np.zeros((nYY,nXX))
lm_interpolated = np.zeros((nYY,nXX))
for j in range(nXX):
  for i in range(nYY):
    if wrf_landmask[0,i,j] == 0:
      hs_interpolated[i,j] = hs_interpolate_fun(wrf_lat[0,i,j],wrf_lon[0,i,j])
      lm_interpolated[i,j] = lm_interpolate_fun(wrf_lat[0,i,j],wrf_lon[0,i,j])

wrf_results.variables['WAVEHS'][0,:,:] = hs_interpolated;
wrf_results.variables['WAVELP'][0,:,:] = lm_interpolated;

wrf_results.close()

plt.imshow(hs_interpolated,vmax=2,vmin=0)
plt.savefig('fig_wavehs.png');
plt.close('all')
plt.imshow(lm_interpolated,vmax=100,vmin=0)
plt.savefig('fig_wavelm.png');
plt.close('all')
